============
gspWeb
============


Installation
============

To install the latest release of ml_processor from PyPi:

.. code-block:: test
	
	pip install gspWeb

Contributing
============
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

License
=======
[MIT](https://choosealicense.com/licenses/mit/)
